searchData={"items":[{"type":"module","title":"Hog","doc":"This process will routinely scans all of the running processes and emit a telemetry\nevent any time a process surpasses a certain memory threshold. The memory threshold\nalong with how often Hog scans all of your running processes is configurable. Once\na memory hungry process is found, a telemetry event is emitted. You can hook into\nthis telemetry event your self to deal with the misbehaving process, or you can use\nthe provided `Hog.Logger` module log process information. Below is a listing of\nall of the configuration options available to you.\n\nSupported options:\n\n* `:scan_interval` (tuple of `t:pos_integer/0`,  values) - The interval for how often the running processes are scanned. The default value is `{1, :minutes}`.\n\n* `:memory_threshold` (tuple of `t:pos_integer/0`,  values) - The memory threshold that determines whether a telemetry event is emitted. The default value is `{100, :megabytes}`.\n\n* `:max_report_frequency` (tuple of `t:pos_integer/0`,  values) - As not to create too many telemetry events about the same process over and over again, you can specify how often a particular process has a telemetry event emitted for it. The check for the process is based on the PID. So if the process crashes and is restarted, it will be reported again since it is running under a new PID. The default value is `{1, :minutes}`.\n\n* `:event_handler` - The handler function that is called when a process surpasses the configured memory_threshold The default value is `&Hog.Logger.default_logger/2`.\n\n* `:additional_pid_info_fields` (list of `t:atom/0`) - The process info fields that are collected on the running process before emitting the telemetry event that memory usage has exceed configure threshold. The fields that are captured by default are: `[:memory, :reductions, :message_queue_len, :current_stacktrace, :registered_name]`. Any additional fields provided will be included in the telemetry event metadata. The default value is `[]`.\n\n\n\nComing soon:\n- ETS table scanning","ref":"Hog.html"},{"type":"function","title":"Hog.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hog.html#child_spec/1"},{"type":"type","title":"Hog.option/0","doc":"","ref":"Hog.html#t:option/0"},{"type":"function","title":"Hog.start_link/1","doc":"","ref":"Hog.html#start_link/1"},{"type":"module","title":"Hog.Logger","doc":"This module provides default loggers for when memory threshold\nwarnings are emitted by Hog.","ref":"Hog.Logger.html"},{"type":"function","title":"Hog.Logger.default_logger/2","doc":"","ref":"Hog.Logger.html#default_logger/2"},{"type":"module","title":"Hog.TelemetryEvents","doc":"This module provides helpers for dealing with the\ntelemetry events emitted by the Hog library.","ref":"Hog.TelemetryEvents.html"},{"type":"function","title":"Hog.TelemetryEvents.attach_memory_threshold_surpassed_handler/1","doc":"","ref":"Hog.TelemetryEvents.html#attach_memory_threshold_surpassed_handler/1"},{"type":"function","title":"Hog.TelemetryEvents.emit_memory_threshold_surpassed_event/4","doc":"This event is emitted when a process surpasses the memory threshold. It contains the following\nmeasurements and metadata:\n\n #### Measurements\n\n* `:process_memory` — the amount of memory consumed by the process (in bytes)\n\n#### Metadata\n\n* `:process_info` - all of the information about the process that exceeded the memory threshold as configured when starting the  `Hog` process.\n* `:pid` — the PID of the offending process\n* `:current_monotonic_time` — the monotonic time when the exceeded memory threshold was detected\n* `:timestamp` - the timestamp when the exceeded memory threshold was detected","ref":"Hog.TelemetryEvents.html#emit_memory_threshold_surpassed_event/4"},{"type":"extras","title":"README","doc":"Pinpoint and deal with memory hungry processes\n \n\n \n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n \n\n \n\n# Contents\n\n- [Installation](#installation)\n- [Supporting Hog](#supporting-hog)\n- [Using Hog](#setting-up-hog)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"[Available in Hex](https://hex.pm/packages/hog), the package can be installed by adding `hog` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hog, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/hog](https://hexdocs.pm/hog).","ref":"readme.html#installation"},{"type":"extras","title":"Supporting Hog - README","doc":"If you rely on this library, it would much appreciated if you can give back to the project\nin order to help ensure its continued development.\n\nCheckout my [GitHub Sponsorship page](https://github.com/sponsors/akoutmos) if you want to help out!","ref":"readme.html#supporting-hog"},{"type":"extras","title":"Gold Sponsors - README","doc":"","ref":"readme.html#gold-sponsors"},{"type":"extras","title":"Silver Sponsors - README","doc":"","ref":"readme.html#silver-sponsors"},{"type":"extras","title":"Bronze Sponsors - README","doc":"","ref":"readme.html#bronze-sponsors"},{"type":"extras","title":"Using Hog - README","doc":"Add `{:hog, \"~> 0.1.0\"}` to your `mix.exs` file and run `mix deps.get`. After installing the dependency,\nyou can add the following line to your `application.ex` file:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    children = [\n      # If the defaults laid out in `Hog` work for your use case, you can have\n      # just `Hog`, else provide your specific options.\n      {Hog, scan_interval: {30, :seconds}, memory_threshold: {100, :megabytes}},\n      ...\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  ...\nend\n```\n\nWith that in place, you can start your application and memory hungry processes will be logged using the `Logger`\nmodule. If the default logging function does not provide adequate information to help track down the memory hungry\nprocess, you can always provide your own `:event_handler` to the `Hog` GenServer via config or even tie into the\n`:telemetry` events yourself using the `Hog.TelemetryEvents` module.","ref":"readme.html#using-hog"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}